#!/bin/bash
#------------------------------------------------------------------
# solaris10_gos_timeout-install.sh
#
# Author:  NetApp, Inc.
# Date:    11-JUN-2008
# Release: 3.1.80.6441
# Purpose: This script will set the required I/O timeout setting and 
#          sd driver parameters on a Solaris 10 Guest OS
#          for connectivity to IBM N Series storage systems.
#
# Note:    This script is required to be run by root.  
#
# Copyright (c) 2008 NetApp, Inc.
# All rights reserved.
#-------------------------------------------------------------------
# Use a 190 second I/O Timeout
IO_TIMEOUT=0xbe
IO_TIMEOUT_DEC=190
REBOOT_NOW=""

# Ensure the user is running as root
USER=`/usr/ucb/whoami`;

if [ "$USER" != "root" ]
then
   echo "";
   echo "This program must be run as root.";
   echo "Exiting.";
   echo "";
   exit 2;
fi;

# Verify this is Solaris 10
cat /etc/release | grep "Solaris 10" > /dev/null 2>&1;
if [[ $? -ne 0 ]]; then
   echo "";
   echo "This script is designed for Solaris 10.";
   echo "Please run the appropriate script for your GOS type.";
   echo "Exiting.";
   echo "";
   exit 4;
fi;




# Set the Global I/O Timeout
cat >> /etc/system <<-EOFA

# I/O Timeout setting (${IO_TIMEOUT_DEC}) required for connectivity to IBM N Series storage systems
set sd:sd_io_time=${IO_TIMEOUT}

EOFA



cat >> /kernel/drv/sd.conf <<-EOFB

# IBM N Series sd driver parameters for RDM and VMFS LUNs.  This is a
# bitmap representation of the set of configuration parameters for the 
# sd disk driver.
#    BIT  Definition
#    ===  ==========
#     0   throttle (max)
#     1   controller type
#     2   fabricate device id
#     3   disable caching
#     4   play BCD
#     5   read subchannel BCD
#     6   read TOC TRK BCD
#     7   read TOC ADDR BCD
#     8   no READ_HDR
#     9   read CD XD4
#    10   not ready retries
#    11   busy retries
#    12   reset retries
#    13   reservation release time
#    14   TUR check
#    15   throttle (min)
#    16   disable disksort
#    17   enable LUN reset
#
# The following parameters are modified:
#    max. throttle = 32
#    not ready retries = 300
#    busy retries = 300
#    reset retries = 30
#    min. throttle = 8
sd-config-list="NETAPP LUN", "ontapRDM-sd-config";
ontapRDM-sd-config=1,0x9c01,32,0,0,0,0,0,0,0,0,0,300,300,30,0,0,8,0,0;

sd-config-list="VMWARE LUN", "vmfs-sd-config";
vmfs-sd-config=1,0x9c01,32,0,0,0,0,0,0,0,0,0,300,300,30,0,0,8,0,0;
#END IBM N Series sd driver parameters
EOFB

echo ""
echo "You must reboot for the changes to take effect."
echo ""
until [ "$REBOOT_NOW" = "yes" ] || [ "$REBOOT_NOW" = "no" ]
do
   echo -n "Do you want to reboot now (yes or no)?> "
   read RESPONSE
   # convert RESPONSE to lowercase
   REBOOT_NOW=`echo $RESPONSE |  tr -s '[:upper:]' '[:lower:]'`
done

if [ "$REBOOT_NOW" = "yes" ]; then
   init 6
else
   echo ""
   echo "You must reboot for the changes to take effect."
   echo ""
fi;



